texlive[58948] Master/texmf-dist/scripts/texlive/tlmgr.pl: fmtutil:

commits+preining at tug.org commits+preining at tug.org
Thu Apr 22 02:44:39 CEST 2021


Revision: 58948
          http://tug.org/svn/texlive?view=revision&revision=58948
Author:   preining
Date:     2021-04-22 02:44:39 +0200 (Thu, 22 Apr 2021)
Log Message:
-----------
fmtutil: put most important command at head of invocation

Modified Paths:
--------------
    trunk/Master/texmf-dist/scripts/texlive/tlmgr.pl

Modified: trunk/Master/texmf-dist/scripts/texlive/tlmgr.pl
===================================================================
--- trunk/Master/texmf-dist/scripts/texlive/tlmgr.pl	2021-04-22 00:44:24 UTC (rev 58947)
+++ trunk/Master/texmf-dist/scripts/texlive/tlmgr.pl	2021-04-22 00:44:39 UTC (rev 58948)
@@ -867,12 +867,13 @@
   my $errors = 0;
 
   my $sysmode = ($opts{"usermode"} ? "-user" : "-sys");
-  my $invoke_fmtutil = "fmtutil$sysmode $common_fmtutil_args";
+  my $fmtutil_cmd = "fmtutil$sysmode";
+  my $fmtutil_args = $common_fmtutil_args;
 
   # of create_formats is unset (NOT the default) we add --refresh so that
   # only existing formats are recreated
   if (!$localtlpdb->option("create_formats")) {
-    $invoke_fmtutil .= " --refresh";
+    $fmtutil_args .= " --refresh";
     debug("only existing formats will be refreshed per user option (create_formats=0)\n");
   }
 
@@ -973,7 +974,7 @@
       for my $e (keys %updated_engines) {
         debug ("updating formats based on $e\n");
         $errors += do_cmd_and_check
-                    ("$invoke_fmtutil --no-error-if-no-format --byengine $e");
+                    ("$fmtutil_cmd --byengine $e --no-error-if-no-format $fmtutil_args");
       }
       # now rebuild all other formats
       for my $f (keys %do_enable) {
@@ -981,7 +982,7 @@
         # ignore disabled formats
         next if !$::execute_actions{'enable'}{'formats'}{$f}{'mode'};
         debug ("(re)creating format dump $f\n");
-        $errors += do_cmd_and_check ("$invoke_fmtutil --byfmt $f");
+        $errors += do_cmd_and_check ("$fmtutil_cmd --byfmt $f $fmtutil_args");
         $done_formats{$f} = 1;
       }
     }
@@ -1000,7 +1001,7 @@
           $lang = "$TEXMFSYSVAR/tex/generic/config/$lang";
         }
         if (!$::regenerate_all_formats) {
-          $errors += do_cmd_and_check ("$invoke_fmtutil --byhyphen \"$lang\"");
+          $errors += do_cmd_and_check ("$fmtutil_cmd --byhyphen \"$lang\" $fmtutil_args");
         }
       }
     }
@@ -1009,8 +1010,8 @@
     # so we just refresh formats instead of generating all that have not been there
     if ($::regenerate_all_formats) {
       info("Regenerating available formats, this may take some time ...");
-      # --refresh might already be in $invoke_fmtutil, but we don't care
-      $errors += do_cmd_and_check("$invoke_fmtutil --refresh --all");
+      # --refresh might already be in $fmtutil_args, but we don't care
+      $errors += do_cmd_and_check("$fmtutil_cmd --all --refresh $fmtutil_args");
       info("done\n");
       $::regenerate_all_formats = 0;
     }



More information about the tex-live-commits mailing list.